@@ -4,8 +4,8 @@ var searchData=
   ['dataaccessdescriptor',['DataAccessDescriptor',['../servicecom_1_1sun_1_1star_1_1sdb_1_1DataAccessDescriptor.html',1,'com::sun::star::sdb']]],
   ['dataaccessdescriptorfactory',['DataAccessDescriptorFactory',['../singletoncom_1_1sun_1_1star_1_1sdb_1_1DataAccessDescriptorFactory.html',1,'com::sun::star::sdb']]],
   ['dataawarecontrolmodel',['DataAwareControlModel',['../servicecom_1_1sun_1_1star_1_1form_1_1DataAwareControlModel.html',1,'com::sun::star::form']]],
-  ['database',['Database',['../servicecom_1_1sun_1_1star_1_1text_1_1fieldmaster_1_1Database.html',1,'com::sun::star::text::fieldmaster']]],
-  ['database',['Database',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Database.html',1,'com::sun::star::text::textfield']]],
+  ['databar',['DataBar',['../servicecom_1_1sun_1_1star_1_1sheet_1_1DataBar.html',1,'com::sun::star::sheet']]],
+  ['database',['Database',['../servicecom_1_1sun_1_1star_1_1text_1_1fieldmaster_1_1Database.html',1,'Database'],['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Database.html',1,'Database']]],
   ['databaseaccess',['DatabaseAccess',['../servicecom_1_1sun_1_1star_1_1sdb_1_1DatabaseAccess.html',1,'com::sun::star::sdb']]],
   ['databaseaccessconnection',['DatabaseAccessConnection',['../servicecom_1_1sun_1_1star_1_1sdb_1_1DatabaseAccessConnection.html',1,'com::sun::star::sdb']]],
   ['databaseaccesscontext',['DatabaseAccessContext',['../servicecom_1_1sun_1_1star_1_1sdb_1_1DatabaseAccessContext.html',1,'com::sun::star::sdb']]],
@@ -91,36 +91,28 @@ var searchData=
   ['dataseries',['DataSeries',['../servicecom_1_1sun_1_1star_1_1chart2_1_1DataSeries.html',1,'com::sun::star::chart2']]],
   ['datasettings',['DataSettings',['../servicecom_1_1sun_1_1star_1_1sdb_1_1DataSettings.html',1,'com::sun::star::sdb']]],
   ['datasink',['DataSink',['../servicecom_1_1sun_1_1star_1_1chart2_1_1data_1_1DataSink.html',1,'com::sun::star::chart2::data']]],
-  ['datasource',['DataSource',['../servicecom_1_1sun_1_1star_1_1sdb_1_1DataSource.html',1,'com::sun::star::sdb']]],
-  ['datasource',['DataSource',['../servicecom_1_1sun_1_1star_1_1chart2_1_1data_1_1DataSource.html',1,'com::sun::star::chart2::data']]],
+  ['datasource',['DataSource',['../servicecom_1_1sun_1_1star_1_1sdb_1_1DataSource.html',1,'DataSource'],['../servicecom_1_1sun_1_1star_1_1chart2_1_1data_1_1DataSource.html',1,'DataSource']]],
   ['datasourceadministrationdialog',['DatasourceAdministrationDialog',['../servicecom_1_1sun_1_1star_1_1sdb_1_1DatasourceAdministrationDialog.html',1,'com::sun::star::sdb']]],
   ['datasourcebrowser',['DataSourceBrowser',['../servicecom_1_1sun_1_1star_1_1sdb_1_1DataSourceBrowser.html',1,'com::sun::star::sdb']]],
   ['datatransferevent',['DataTransferEvent',['../structcom_1_1sun_1_1star_1_1io_1_1DataTransferEvent.html',1,'com::sun::star::io']]],
   ['datatruncation',['DataTruncation',['../exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html',1,'com::sun::star::sdbc']]],
-  ['date',['Date',['../structcom_1_1sun_1_1star_1_1util_1_1Date.html',1,'com::sun::star::util']]],
-  ['date',['Date',['../servicecom_1_1sun_1_1star_1_1xsd_1_1Date.html',1,'com::sun::star::xsd']]],
-  ['date',['Date',['../structcom_1_1sun_1_1star_1_1bridge_1_1oleautomation_1_1Date.html',1,'com::sun::star::bridge::oleautomation']]],
-  ['datefield',['DateField',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1DateField.html',1,'com::sun::star::form::component']]],
-  ['datefield',['DateField',['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1DateField.html',1,'com::sun::star::form::control']]],
-  ['datetime',['DateTime',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DateTime.html',1,'com::sun::star::text::textfield']]],
-  ['datetime',['DateTime',['../structcom_1_1sun_1_1star_1_1util_1_1DateTime.html',1,'com::sun::star::util']]],
-  ['datetime',['DateTime',['../servicecom_1_1sun_1_1star_1_1xsd_1_1DateTime.html',1,'com::sun::star::xsd']]],
-  ['datetime',['DateTime',['../servicecom_1_1sun_1_1star_1_1presentation_1_1textfield_1_1DateTime.html',1,'com::sun::star::presentation::textfield']]],
+  ['date',['Date',['../structcom_1_1sun_1_1star_1_1util_1_1Date.html',1,'Date'],['../servicecom_1_1sun_1_1star_1_1xsd_1_1Date.html',1,'Date'],['../structcom_1_1sun_1_1star_1_1bridge_1_1oleautomation_1_1Date.html',1,'Date']]],
+  ['datecondition',['DateCondition',['../servicecom_1_1sun_1_1star_1_1sheet_1_1DateCondition.html',1,'com::sun::star::sheet']]],
+  ['datefield',['DateField',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1DateField.html',1,'DateField'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1DateField.html',1,'DateField']]],
+  ['datetime',['DateTime',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DateTime.html',1,'DateTime'],['../structcom_1_1sun_1_1star_1_1util_1_1DateTime.html',1,'DateTime'],['../servicecom_1_1sun_1_1star_1_1xsd_1_1DateTime.html',1,'DateTime'],['../servicecom_1_1sun_1_1star_1_1presentation_1_1textfield_1_1DateTime.html',1,'DateTime']]],
   ['datetimerange',['DateTimeRange',['../structcom_1_1sun_1_1star_1_1util_1_1DateTimeRange.html',1,'com::sun::star::util']]],
   ['datetimeshape',['DateTimeShape',['../servicecom_1_1sun_1_1star_1_1presentation_1_1DateTimeShape.html',1,'com::sun::star::presentation']]],
   ['datetimewithtimezone',['DateTimeWithTimezone',['../structcom_1_1sun_1_1star_1_1util_1_1DateTimeWithTimezone.html',1,'com::sun::star::util']]],
   ['datewithtimezone',['DateWithTimezone',['../structcom_1_1sun_1_1star_1_1util_1_1DateWithTimezone.html',1,'com::sun::star::util']]],
   ['day',['Day',['../servicecom_1_1sun_1_1star_1_1xsd_1_1Day.html',1,'com::sun::star::xsd']]],
   ['dbaseconnectionproperties',['DBASEConnectionProperties',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1DBASEConnectionProperties.html',1,'com::sun::star::sdbc']]],
-  ['dde',['DDE',['../servicecom_1_1sun_1_1star_1_1text_1_1fieldmaster_1_1DDE.html',1,'com::sun::star::text::fieldmaster']]],
-  ['dde',['DDE',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DDE.html',1,'com::sun::star::text::textfield']]],
+  ['dde',['DDE',['../servicecom_1_1sun_1_1star_1_1text_1_1fieldmaster_1_1DDE.html',1,'DDE'],['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DDE.html',1,'DDE']]],
   ['ddeiteminfo',['DDEItemInfo',['../structcom_1_1sun_1_1star_1_1sheet_1_1DDEItemInfo.html',1,'com::sun::star::sheet']]],
   ['ddelink',['DDELink',['../servicecom_1_1sun_1_1star_1_1sheet_1_1DDELink.html',1,'com::sun::star::sheet']]],
   ['ddelinkinfo',['DDELinkInfo',['../structcom_1_1sun_1_1star_1_1sheet_1_1DDELinkInfo.html',1,'com::sun::star::sheet']]],
   ['ddelinks',['DDELinks',['../servicecom_1_1sun_1_1star_1_1sheet_1_1DDELinks.html',1,'com::sun::star::sheet']]],
   ['ddelinksenumeration',['DDELinksEnumeration',['../servicecom_1_1sun_1_1star_1_1sheet_1_1DDELinksEnumeration.html',1,'com::sun::star::sheet']]],
-  ['decimal',['Decimal',['../servicecom_1_1sun_1_1star_1_1xsd_1_1Decimal.html',1,'com::sun::star::xsd']]],
-  ['decimal',['Decimal',['../structcom_1_1sun_1_1star_1_1bridge_1_1oleautomation_1_1Decimal.html',1,'com::sun::star::bridge::oleautomation']]],
+  ['decimal',['Decimal',['../servicecom_1_1sun_1_1star_1_1xsd_1_1Decimal.html',1,'Decimal'],['../structcom_1_1sun_1_1star_1_1bridge_1_1oleautomation_1_1Decimal.html',1,'Decimal']]],
   ['decryptor',['Decryptor',['../servicecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1Decryptor.html',1,'com::sun::star::xml::crypto::sax']]],
   ['defaultbackend',['DefaultBackend',['../servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1DefaultBackend.html',1,'com::sun::star::configuration::backend']]],
   ['defaultcomponentinspectormodel',['DefaultComponentInspectorModel',['../servicecom_1_1sun_1_1star_1_1report_1_1inspection_1_1DefaultComponentInspectorModel.html',1,'com::sun::star::report::inspection']]],
@@ -133,23 +125,20 @@ var searchData=
   ['defaultnumberingprovider',['DefaultNumberingProvider',['../servicecom_1_1sun_1_1star_1_1text_1_1DefaultNumberingProvider.html',1,'com::sun::star::text']]],
   ['defaultprovider',['DefaultProvider',['../servicecom_1_1sun_1_1star_1_1configuration_1_1DefaultProvider.html',1,'com::sun::star::configuration']]],
   ['defaultregistry',['DefaultRegistry',['../servicecom_1_1sun_1_1star_1_1registry_1_1DefaultRegistry.html',1,'com::sun::star::registry']]],
-  ['defaults',['Defaults',['../servicecom_1_1sun_1_1star_1_1drawing_1_1Defaults.html',1,'com::sun::star::drawing']]],
-  ['defaults',['Defaults',['../servicecom_1_1sun_1_1star_1_1text_1_1Defaults.html',1,'com::sun::star::text']]],
+  ['defaults',['Defaults',['../servicecom_1_1sun_1_1star_1_1drawing_1_1Defaults.html',1,'Defaults'],['../servicecom_1_1sun_1_1star_1_1text_1_1Defaults.html',1,'Defaults']]],
   ['defaultviewcontroller',['DefaultViewController',['../servicecom_1_1sun_1_1star_1_1sdb_1_1application_1_1DefaultViewController.html',1,'com::sun::star::sdb::application']]],
   ['definitioncontainer',['DefinitionContainer',['../servicecom_1_1sun_1_1star_1_1sdb_1_1DefinitionContainer.html',1,'com::sun::star::sdb']]],
   ['definitioncontent',['DefinitionContent',['../servicecom_1_1sun_1_1star_1_1sdb_1_1DefinitionContent.html',1,'com::sun::star::sdb']]],
   ['dependencyexception',['DependencyException',['../exceptioncom_1_1sun_1_1star_1_1deployment_1_1DependencyException.html',1,'com::sun::star::deployment']]],
   ['dependenttextfield',['DependentTextField',['../servicecom_1_1sun_1_1star_1_1text_1_1DependentTextField.html',1,'com::sun::star::text']]],
-  ['deploymentexception',['DeploymentException',['../exceptioncom_1_1sun_1_1star_1_1deployment_1_1DeploymentException.html',1,'com::sun::star::deployment']]],
-  ['deploymentexception',['DeploymentException',['../exceptioncom_1_1sun_1_1star_1_1uno_1_1DeploymentException.html',1,'com::sun::star::uno']]],
+  ['deploymentexception',['DeploymentException',['../exceptioncom_1_1sun_1_1star_1_1deployment_1_1DeploymentException.html',1,'DeploymentException'],['../exceptioncom_1_1sun_1_1star_1_1uno_1_1DeploymentException.html',1,'DeploymentException']]],
   ['description',['Description',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1Description.html',1,'com::sun::star::text::textfield::docinfo']]],
   ['descriptor',['Descriptor',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1Descriptor.html',1,'com::sun::star::sdbcx']]],
   ['desktop',['Desktop',['../servicecom_1_1sun_1_1star_1_1frame_1_1Desktop.html',1,'com::sun::star::frame']]],
   ['desktoptask',['DesktopTask',['../servicecom_1_1sun_1_1star_1_1frame_1_1DesktopTask.html',1,'com::sun::star::frame']]],
   ['desktoptasks',['DesktopTasks',['../servicecom_1_1sun_1_1star_1_1frame_1_1DesktopTasks.html',1,'com::sun::star::frame']]],
   ['deviceinfo',['DeviceInfo',['../structcom_1_1sun_1_1star_1_1awt_1_1DeviceInfo.html',1,'com::sun::star::awt']]],
-  ['diagram',['Diagram',['../servicecom_1_1sun_1_1star_1_1chart_1_1Diagram.html',1,'com::sun::star::chart']]],
-  ['diagram',['Diagram',['../servicecom_1_1sun_1_1star_1_1chart2_1_1Diagram.html',1,'com::sun::star::chart2']]],
+  ['diagram',['Diagram',['../servicecom_1_1sun_1_1star_1_1chart_1_1Diagram.html',1,'Diagram'],['../servicecom_1_1sun_1_1star_1_1chart2_1_1Diagram.html',1,'Diagram']]],
   ['dialogclosedevent',['DialogClosedEvent',['../structcom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1DialogClosedEvent.html',1,'com::sun::star::ui::dialogs']]],
   ['dialogprovider',['DialogProvider',['../servicecom_1_1sun_1_1star_1_1awt_1_1DialogProvider.html',1,'com::sun::star::awt']]],
   ['dialogprovider2',['DialogProvider2',['../servicecom_1_1sun_1_1star_1_1awt_1_1DialogProvider2.html',1,'com::sun::star::awt']]],
@@ -197,10 +186,7 @@ var searchData=
   ['documentrevisionlistpersistence',['DocumentRevisionListPersistence',['../servicecom_1_1sun_1_1star_1_1document_1_1DocumentRevisionListPersistence.html',1,'com::sun::star::document']]],
   ['documentsaverequest',['DocumentSaveRequest',['../exceptioncom_1_1sun_1_1star_1_1sdb_1_1DocumentSaveRequest.html',1,'com::sun::star::sdb']]],
   ['documentscriptlibrarycontainer',['DocumentScriptLibraryContainer',['../servicecom_1_1sun_1_1star_1_1script_1_1DocumentScriptLibraryContainer.html',1,'com::sun::star::script']]],
-  ['documentsettings',['DocumentSettings',['../servicecom_1_1sun_1_1star_1_1presentation_1_1DocumentSettings.html',1,'com::sun::star::presentation']]],
-  ['documentsettings',['DocumentSettings',['../servicecom_1_1sun_1_1star_1_1sheet_1_1DocumentSettings.html',1,'com::sun::star::sheet']]],
-  ['documentsettings',['DocumentSettings',['../servicecom_1_1sun_1_1star_1_1drawing_1_1DocumentSettings.html',1,'com::sun::star::drawing']]],
-  ['documentsettings',['DocumentSettings',['../servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html',1,'com::sun::star::text']]],
+  ['documentsettings',['DocumentSettings',['../servicecom_1_1sun_1_1star_1_1drawing_1_1DocumentSettings.html',1,'DocumentSettings'],['../servicecom_1_1sun_1_1star_1_1sheet_1_1DocumentSettings.html',1,'DocumentSettings'],['../servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html',1,'DocumentSettings'],['../servicecom_1_1sun_1_1star_1_1presentation_1_1DocumentSettings.html',1,'DocumentSettings']]],
   ['documentsignatureinformation',['DocumentSignatureInformation',['../structcom_1_1sun_1_1star_1_1security_1_1DocumentSignatureInformation.html',1,'com::sun::star::security']]],
   ['documenttemplates',['DocumentTemplates',['../servicecom_1_1sun_1_1star_1_1frame_1_1DocumentTemplates.html',1,'com::sun::star::frame']]],
   ['domexception',['DOMException',['../exceptioncom_1_1sun_1_1star_1_1xml_1_1dom_1_1DOMException.html',1,'com::sun::star::xml::dom']]],
@@ -213,11 +199,9 @@ var searchData=
   ['drawingdocument',['DrawingDocument',['../servicecom_1_1sun_1_1star_1_1drawing_1_1DrawingDocument.html',1,'com::sun::star::drawing']]],
   ['drawingdocumentdrawview',['DrawingDocumentDrawView',['../servicecom_1_1sun_1_1star_1_1drawing_1_1DrawingDocumentDrawView.html',1,'com::sun::star::drawing']]],
   ['drawingdocumentfactory',['DrawingDocumentFactory',['../servicecom_1_1sun_1_1star_1_1drawing_1_1DrawingDocumentFactory.html',1,'com::sun::star::drawing']]],
-  ['drawpage',['DrawPage',['../servicecom_1_1sun_1_1star_1_1drawing_1_1DrawPage.html',1,'com::sun::star::drawing']]],
-  ['drawpage',['DrawPage',['../servicecom_1_1sun_1_1star_1_1presentation_1_1DrawPage.html',1,'com::sun::star::presentation']]],
+  ['drawpage',['DrawPage',['../servicecom_1_1sun_1_1star_1_1drawing_1_1DrawPage.html',1,'DrawPage'],['../servicecom_1_1sun_1_1star_1_1presentation_1_1DrawPage.html',1,'DrawPage']]],
   ['drawpages',['DrawPages',['../servicecom_1_1sun_1_1star_1_1drawing_1_1DrawPages.html',1,'com::sun::star::drawing']]],
-  ['driver',['Driver',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1Driver.html',1,'com::sun::star::sdbc']]],
-  ['driver',['Driver',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1Driver.html',1,'com::sun::star::sdbcx']]],
+  ['driver',['Driver',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1Driver.html',1,'Driver'],['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1Driver.html',1,'Driver']]],
   ['drivermanager',['DriverManager',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1DriverManager.html',1,'com::sun::star::sdbc']]],
   ['driverpropertyinfo',['DriverPropertyInfo',['../structcom_1_1sun_1_1star_1_1sdbc_1_1DriverPropertyInfo.html',1,'com::sun::star::sdbc']]],
   ['dropcapformat',['DropCapFormat',['../structcom_1_1sun_1_1star_1_1style_1_1DropCapFormat.html',1,'com::sun::star::style']]],
